***** Replication code for all figures and tables (except Figure 1) in Dahl et al. (2021) "Caught between Cultures: Unintended Consequences of Improving Opportunity for ImImmig Girls" and the corresponding appendix ***

clear
clear matrix
capture log close
set more off

* Enter your global pathway to the project in the following line instead of ... *

global DataC "...\Replication\Data\Clean"
global OutputT "...\Replication\Output\Tables"
global OutputF "...\Replication\Output\Figures"



/********************** DATASET **********************************/
use "$DataC\data_for_estimation", clear
global FAMILY "Edum_l Edum_m Edum_h Edum_miss Age_Mother i.Age_Mother_Missing Eduf_l Eduf_m Eduf_h Eduf_miss Age_Father i.Age_Father_Missing"
global CITY "City_small Alo_male Alo_female Alo_Ausl Alo_Jugend"


/********************** FIGURES ***************************/

/*** Figure 2 ***/

preserve
drop if Immig==.


gen window1=.
replace window1=1 if Bmonth_centered>=-6 & Bmonth_centered<=5
gen window2=.
replace window2=1 if Bmonth_centered>=-5 & Bmonth_centered<=4
gen window3=.
replace window3=1 if Bmonth_centered>=-4 & Bmonth_centered<=3
gen window4=.
replace window4=1 if Bmonth_centered>=-3 & Bmonth_centered<=2
gen window5=.
replace window5=1 if Bmonth_centered>=-2 & Bmonth_centered<=1

foreach x in 1 2 3 4 5 {
sum z_ls if Immig==0 & Female==1 & Post==0 & window`x'==1
return list
gen ls_pre_ng`x'=.
replace ls_pre_ng`x'=r(mean) if Immig==0 & Female==1 & Post==0 & window`x'==1
sum z_ls if Immig==0 & Female==1 & Post==1 & window`x'==1
return list
gen ls_post_ng`x'=.
replace ls_post_ng`x'=r(mean) if Immig==0 & Female==1 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum z_ls if Immig==1 & Female==1 & Post==0 & window`x'==1
return list
gen ls_pre_fg`x'=.
replace ls_pre_fg`x'=r(mean) if Immig==1 & Female==1 & Post==0 & window`x'==1
sum z_ls if Immig==1 & Female==1 & Post==1 & window`x'==1
return list
gen ls_post_fg`x'=.
replace ls_post_fg`x'=r(mean) if Immig==1 & Female==1 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum z_ls if Immig==1 & Female==0 & Post==0 & window`x'==1
return list
gen ls_pre_fb`x'=.
replace ls_pre_fb`x'=r(mean) if Immig==1 & Female==0 & Post==0 & window`x'==1
sum z_ls if Immig==1 & Female==0 & Post==1 & window`x'==1
return list
gen ls_post_fb`x'=.
replace ls_post_fb`x'=r(mean) if Immig==1 & Female==0 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum z_ls if Immig==0 & Female==0 & Post==0 & window`x'==1
return list
gen ls_pre_nb`x'=.
replace ls_pre_nb`x'=r(mean) if Immig==0 & Female==0 & Post==0 & window`x'==1
sum z_ls if Immig==0 & Female==0 & Post==1 & window`x'==1
return list
gen ls_post_nb`x'=.
replace ls_post_nb`x'=r(mean) if Immig==0 & Female==1 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum Lifesatisfaction if Immig==0 & Female==1 & Post==0 & window`x'==1
return list
gen qf_pre_ng`x'=.
replace qf_pre_ng`x'=r(mean) if Immig==0 & Female==1 & Post==0 & window`x'==1
sum Lifesatisfaction if Immig==0 & Female==1 & Post==1 & window`x'==1
return list
gen qf_post_ng`x'=.
replace qf_post_ng`x'=r(mean) if Immig==0 & Female==1 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum Lifesatisfaction if Immig==1 & Female==1 & Post==0 & window`x'==1
return list
gen qf_pre_fg`x'=.
replace qf_pre_fg`x'=r(mean) if Immig==1 & Female==1 & Post==0 & window`x'==1
sum Lifesatisfaction if Immig==1 & Female==1 & Post==1 & window`x'==1
return list
gen qf_post_fg`x'=.
replace qf_post_fg`x'=r(mean) if Immig==1 & Female==1 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum Lifesatisfaction if Immig==1 & Female==0 & Post==0 & window`x'==1
return list
gen qf_pre_fb`x'=.
replace qf_pre_fb`x'=r(mean) if Immig==1 & Female==0 & Post==0 & window`x'==1
sum Lifesatisfaction if Immig==1 & Female==0 & Post==1 & window`x'==1
return list
gen qf_post_fb`x'=.
replace qf_post_fb`x'=r(mean) if Immig==1 & Female==0 & Post==1 & window`x'==1
}

foreach x in 1 2 3 4 5 {
sum Lifesatisfaction if Immig==0 & Female==0 & Post==0 & window`x'==1
return list
gen qf_pre_nb`x'=.
replace qf_pre_nb`x'=r(mean) if Immig==0 & Female==0 & Post==0 & window`x'==1
sum Lifesatisfaction if Immig==0 & Female==0 & Post==1 & window`x'==1
return list
gen qf_post_nb`x'=.
replace qf_post_nb`x'=r(mean) if Immig==0 & Female==1 & Post==1 & window`x'==1
}

reshape long ls_pre_ng ls_post_ng ls_pre_fg ls_post_fg ls_pre_nb ls_post_nb ls_pre_fb ls_post_fb qf_pre_ng qf_post_ng qf_pre_fg qf_post_fg qf_pre_nb qf_post_nb qf_pre_fb qf_post_fb, i(ID) j(est_win)
collapse ls_pre_ng ls_post_ng ls_pre_fg ls_post_fg ls_pre_nb ls_post_nb ls_pre_fb ls_post_fb qf_pre_ng qf_post_ng qf_pre_fg qf_post_fg qf_pre_nb qf_post_nb qf_pre_fb qf_post_fb, by(est_win)

gen est_win_gpre=est_win*2-0.5
gen est_win_gpos=est_win*2-0.25
gen est_win_bpre=est_win*2+0.25
gen est_win_bpos=est_win*2+0.5


twoway (scatter ls_pre_fb est_win) (scatter ls_post_fb est_win), xlabel(1 "+/- 6 mo." 2 "+/- 5 mo." 3 "+/- 4 mo." 4 "+/- 3 mo." 5 "+/- 2 mo.") xtitle("Sample Window") ysc(r(-1 1)) ylabel(-1 (0.4) 1)  xsc(r(0.5 5.5)) ytitle("Mean of Standardized" "Life Satisfaction", size(small))  legend(row(1) size(*0.8) region(lstyle(none) color(gs16)) nobox  order(1 "Born Pre-Reform" 2 "Born Post-Reform")) title(Panel B: Immigrant Boys, size(medium)) saving(iboys, replace) plotregion(fcolor(white)) graphregion(fcolor(white) style(none) color(gs16))
twoway (scatter ls_pre_nb est_win) (scatter ls_post_nb est_win), xlabel(1 "+/- 6 mo." 2 "+/- 5 mo." 3 "+/- 4 mo." 4 "+/- 3 mo." 5 "+/- 2 mo.") xtitle("Sample Window") ysc(r(-1 1)) ylabel(-1 (0.4) 1) xsc(r(0.5 5.5)) ytitle("Mean of Standardized" "Life Satisfaction", size(small))  legend(row(1) size(*0.8) region(lstyle(none) color(gs16)) nobox order(1 "Born Pre-Reform" 2 "Born Post-Reform")) title(Panel D: Native Boys, size(medium)) saving(nboys, replace) plotregion(fcolor(white)) graphregion(fcolor(white) style(none) color(gs16))
twoway (scatter ls_pre_fg est_win) (scatter ls_post_fg est_win), xlabel(1 "+/- 6 mo." 2 "+/- 5 mo." 3 "+/- 4 mo." 4 "+/- 3 mo." 5 "+/- 2 mo.") xtitle("Sample Window") ysc(r(-1 1)) ylabel(-1 (0.4) 1) xsc(r(0.5 5.5)) ytitle("Mean of Standardized" "Life Satisfaction", size(small))  legend(row(1) size(*0.8) region(lstyle(none) color(gs16)) nobox order(1 "Born Pre-Reform" 2 "Born Post-Reform")) title(Panel A: Immigrant Girls, size(medium)) saving(igirls, replace) plotregion(fcolor(white)) graphregion(fcolor(white) style(none) color(gs16))
twoway (scatter ls_pre_ng est_win) (scatter ls_post_ng est_win), xlabel(1 "+/- 6 mo." 2 "+/- 5 mo." 3 "+/- 4 mo." 4 "+/- 3 mo." 5 "+/- 2 mo.") xtitle("Sample Window") ysc(r(-1 1)) ylabel(-1 (0.4) 1) xsc(r(0.5 5.5)) ytitle("Mean of Standardized" "Life Satisfaction", size(small))  legend(row(1) size(*0.8) region(lstyle(none) color(gs16)) nobox order(1 "Born Pre-Reform" 2 "Born Post-Reform")) title(Panel C: Native Girls, size(medium)) saving(ngirls, replace) plotregion(fcolor(white)) graphregion(fcolor(white) style(none) color(gs16))

grc1leg igirls.gph iboys.gph ngirls.gph nboys.gph, legendfrom(igirls.gph) cols(2) saving("$OutputF\Figure2.gph", replace) plotregion(fcolor(white)) graphregion(fcolor(white) style(none) color(gs16))

restore





/********************* TABLES ****************/

/*** Table 1: Impact of Birthright Citizenship on Subjective Well-Being ***/

*Girls
xi: reg z_ls Post Immig Treat if Female==1
outreg2 using "$OutputT\Table1_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered if Female==1
outreg2 using "$OutputT\Table1_PanelA.tex", append keep(Immig Treat)  stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY if Female==1
outreg2 using "$OutputT\Table1_PanelA.tex", append keep(Immig Treat)  stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1
outreg2 using "$OutputT\Table1_PanelA.tex", append keep(Immig Treat)  stats(coef se) tex nocons nor2

*Boys
xi: reg z_ls Post Immig Treat  if Female==0
outreg2 using "$OutputT\Table1_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered if Female==0
outreg2 using "$OutputT\Table1_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY if Female==0
outreg2 using "$OutputT\Table1_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY  $CITY if Female==0
outreg2 using "$OutputT\Table1_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2




/*** Table 2: Narrowing the Sample Window ***/

preserve
keep if Bmonth_centered>=-5 & Bmonth_centered<=4
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY    if Female==0
outreg2 using "$OutputT\Table2_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY $CITY   if Female==1
outreg2 using "$OutputT\Table2_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2

keep if Bmonth_centered>=-4 & Bmonth_centered<=3
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY    if Female==0
outreg2 using "$OutputT\Table2_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY $CITY   if Female==1
outreg2 using "$OutputT\Table2_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

keep if Bmonth_centered>=-3 & Bmonth_centered<=2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==0
outreg2 using "$OutputT\Table2_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY $CITY    if Female==1
outreg2 using "$OutputT\Table2_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


keep if Bmonth_centered>=-2 & Bmonth_centered<=1
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==0
outreg2 using "$OutputT\Table2_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered  $FAMILY $CITY    if Female==1
outreg2 using "$OutputT\Table2_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
restore 



/*** Table 3: Additional Robustness Checks ***/ 

gen Int=Post*c.Bday_centered
gen weight=max(0,(181-Bday_centered)/181) if Post==1
replace weight=max(0,(184-abs(Bday_centered))/181) if Post==0
replace weight=0.00001 if weight==0

gen Int2=Post*c.Bday_centered
gen Int3=Immig*c.Bday_centered
gen Int4=Immig*Post*c.Bday_centered


*Girls
xi: reg z_ls Post Int c.Bday_centered $FAMILY $CITY if Female==1 & Immig==1 [pw=weight] 
outreg2 using "$OutputT\Table3_PanelA.tex", replace keep(Post) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Bday_centered Treat Int2 Int3 Int4  $FAMILY $CITY if Female==1 [pw=weight]
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig_first Treat_first i.Bmonth_centered $FAMILY $CITY if Female==1 
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig_first Treat_first) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig_FirstNatives Treat_FirstNatives i.Bmonth_centered $FAMILY $CITY if Female==1 
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig_FirstNatives Treat_FirstNatives) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY i.School_ID if Female==1 
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat c.Bday_centered $FAMILY $CITY if Female==1
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Bweek_centered<-1 | Bweek_centered>0)
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1, cluster(School_ID)
outreg2 using "$OutputT\Table3_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 


*Boys
xi: reg z_ls Post Int Bday_centered $FAMILY $CITY if Female==0 & Immig==1 [pw=weight]
outreg2 using "$OutputT\Table3_PanelB.tex", replace keep(Post) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Bday_centered Treat Int2 Int3 Int4  $FAMILY $CITY if Female==0 [pw=weight]
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig_first Treat_first i.Bmonth_centered $FAMILY $CITY if Female==0 
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig_first Treat_first) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig_FirstNatives Treat_FirstNatives i.Bmonth_centered $FAMILY $CITY if Female==0 
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig_FirstNatives Treat_FirstNatives) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY i.School_ID if Female==0
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat c.Bday_centered $FAMILY $CITY if Female==0
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Bweek_centered<-1 | Bweek_centered>0) 
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0, cluster(School_ID) 
outreg2 using "$OutputT\Table3_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2 


/*** Table 4: Self-Esteem as an Alternative Measure of Well-Being ***/

*Girls
xi: reg SE_pos_index Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1
outreg2 using "$OutputT\Table4_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_a Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1  & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_c Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_d Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_g Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_j Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==1 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

*** Boys
xi: reg SE_pos_index Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==0
outreg2 using "$OutputT\Table4_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_a Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==0 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_c Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==0 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_d Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==0 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_g Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==0 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg se_j Post Immig Treat i.Bmonth_centered  $FAMILY $CITY if Female==0 & SE_pos_index!=.
outreg2 using "$OutputT\Table4_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


/*** Table 5: Muslim vs. Non-Muslim ImImmigs ***/

xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table5_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY  if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table5_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table5_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table5_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


/*** Table 6: Social Integration and German Idenity ***/

xi: reg index_participation Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg index_participation Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg index_participation Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg index_participation Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg Support Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Support Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Support Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Support Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY  if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg Lonely Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Lonely Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Lonely Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Lonely Post Immig Treat i.Bmonth_centered $FAMILY $CITY  if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
 
xi: reg German Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg German Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg German Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg German Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table6_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


/*** Table 7: Parental Investments ***/

xi: reg Noinvest_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table7_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Noinvest_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table7_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Noinvest_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table7_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Noinvest_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table7_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg Noinvest_reg_Low Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table7_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Noinvest_reg_Low Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table7_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Noinvest_reg_Low Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table7_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Noinvest_reg_Low Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table7_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg Nogerman_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table7_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Nogerman_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table7_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Nogerman_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table7_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Nogerman_reg Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table7_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


/*** Table 8: Aspirations, Expectations, Disillusionment ***/

xi: reg tertiary Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg tertiary Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg tertiary Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg tertiary Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
 
xi: reg Prob_training Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Prob_training Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Prob_training Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Prob_training Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg joint Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg joint Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg joint Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg joint Post Immig Treat i.Bmonth_centered $FAMILY $CITY  if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg joint_disill_invest Post Immig Treat i.Bmonth_centered $FAMILY $CITY  if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg joint_disill_invest Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg joint_disill_invest Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg joint_disill_invest Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg Prob_Career_Tradeoff Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Prob_Career_Tradeoff Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Prob_Career_Tradeoff Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Prob_Career_Tradeoff Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table8_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


/*** Table 9: Expected Future Change in Life Satisfaction ***/

xi: reg increaseLS Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table9_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg increaseLS Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table9_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg increaseLS Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\Table9_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg increaseLS Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\Table9_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2


/*** Table 10: Evidence on Alternative Mechanisms ***/

xi: reg  Workharder Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg  Workharder Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Workharder Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", replace keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg  Workharder Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY  if Female==1 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

xi: reg Germansucceed Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Germansucceed Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg  Germansucceed Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg Germansucceed Post Immig Treat i.Bmonth_centered $FAMILY $CITY $CITY  if Female==1 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2

preserve
keep if Sis_young>=1
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
restore

preserve
keep if Broth_young>=1
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
restore

preserve
keep if Sis_young<1
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelB.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
restore

preserve
keep if Broth_young<1
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & muslim==0)), cluster(School_ID)
outreg2 using "$OutputT\Table10_PanelA.tex", append keep(Immig Treat) stats(coef se) tex nocons nor2
restore




/*******************APPENDIX TABLES *********************************/

/*** Table A1: Descriptive Statistics ***/

global BACK "Edum_l Edum_m Edum_h Edum_miss Age_Mother Eduf_l Eduf_m Eduf_h Eduf_miss Age_Father"
global REGI "City_small Alo_male Alo_female Alo_Ausl Alo_Jugend"


* Girls
preserve
keep if Immig!=.
keep if Female==1

quietly{
log using "$OutputT\TableA1_PanelA.tex", text replace
noisily di "Variable & Natives & Immigrants  & Immigrants born pre-policy & Immigrants born post-policy  & p-Value \\ \midline"
noisily di " & (1) & (2)  & (3) & (4)  & (3)-(4) \\ \midline"
foreach var in $BACK $REGI {

		foreach mig in 0 1{
			qui su `var' if Immig == `mig' 
			local m`mig' = r(mean)
			local se`mig' = r(sd)/sqrt(r(N))
		}

	qui reg `var' Mig_Status, cluster($CLUSTER)
	mat b=e(b)
	mat V=e(V)
	
	local d = b[1,1]
	local v = V[1,1]
	local z = (`d')/sqrt(`v')
	local p = 2*(1-normal(abs(`z')))

		foreach post in 0 1{
			qui su `var' if Post == `post' & Mig_Status==1 
			local mi`post' = r(mean)
			local sei`post' = r(sd)/sqrt(r(N))
		}
	
	qui reg `var' Post if Mig_Status==1, cluster($CLUSTER)
	mat b=e(b)
	mat V=e(V)
	
	local d = b[1,1]
	local v = V[1,1]
	local z = (`d')/sqrt(`v')
	local pi = 2*(1-normal(abs(`z')))

	
	local n : variable label `var'
	noisily display "`n'" _col(30) "&" round(`m0',.01) _col (30) "&" round(`m1',.01) _col(40)  "&" round(`mi0',.01) _col (30) "&" round(`mi1',.01) _col(40) "&" round(`pi',.01) "\\" 
	} 
log close
}

restore

* Boys
preserve
keep if Immig!=.
keep if Female==0


quietly{
log using "$OutputT\TableA1_PanelB.tex", text replace
noisily di "Variable & Natives & Immigrants  & Immigrants born pre-policy & Immigrants born post-policy  & p-Value \\ \midline"
noisily di " & (1) & (2)  & (3) & (4)  & (3)-(4) \\ \midline"
foreach var in $BACK $REGI {

		foreach mig in 0 1{
			qui su `var' if Immig == `mig' 
			local m`mig' = r(mean)
			local se`mig' = r(sd)/sqrt(r(N))
		}

	qui reg `var' Mig_Status, cluster($CLUSTER)
	mat b=e(b)
	mat V=e(V)
	
	local d = b[1,1]
	local v = V[1,1]
	local z = (`d')/sqrt(`v')
	local p = 2*(1-normal(abs(`z')))

		foreach post in 0 1{
			qui su `var' if Post == `post' & Mig_Status==1 
			local mi`post' = r(mean)
			local sei`post' = r(sd)/sqrt(r(N))
		}
	
	qui reg `var' Post if Mig_Status==1, cluster($CLUSTER)
	mat b=e(b)
	mat V=e(V)
	
	local d = b[1,1]
	local v = V[1,1]
	local z = (`d')/sqrt(`v')
	local pi = 2*(1-normal(abs(`z')))

	
	local n : variable label `var'
	noisily di "`n'" _col(30) "&" round(`m0',.01) _col (30) "&" round(`m1',.01) _col(40) "&" round(`mi0',.01) _col (30) "&" round(`mi1',.01) _col(40) "&" round(`pi',.01) "\\"
}
log close
}
restore



/*** Table A2: Descriptive Statistics for Religious Affiliation and Country of Origin ***/

preserve
eststo ng: quietly estpost summarize Catholic Protestant Muslim None Other_Missing Germany Turkey Balcan Eastern_Europe Post_Soviet Southern_Europe Central_Northern_Europe Middle_East Asia Afric Rest_of_World Unidentified if Immig==0 & Female==1
eststo nb: quietly estpost summarize Catholic Protestant Muslim None Other_Missing Germany Turkey Balcan Eastern_Europe Post_Soviet Southern_Europe Central_Northern_Europe Middle_East Asia Afric Rest_of_World Unidentified if Immig==0 & Female==0
eststo ig: quietly estpost summarize Catholic Protestant Muslim None Other_Missing Germany Turkey Balcan Eastern_Europe Post_Soviet Southern_Europe Central_Northern_Europe Middle_East Asia Afric Rest_of_World Unidentified if Immig==1 & Female==1
eststo ib: quietly estpost summarize Catholic Protestant Muslim None Other_Missing Germany Turkey Balcan Eastern_Europe Post_Soviet Southern_Europe Central_Northern_Europe Middle_East Asia Afric Rest_of_World Unidentified if Immig==1 & Female==0
esttab ng nb ig ib using "$OutputT\TableA2.tex", cells("mean(fmt(2))") replace
restore


/*** Table A3: Descriptive Statistics for Dependent Variables ***/

preserve
keep if Immig==0
keep Lifesatisfaction Selfesteem_a Selfesteem_b Selfesteem_c Selfesteem_d Selfesteem_e Lonely_a Lonely_b Lonely_c Friendshipsupport_a Friendshipsupport_b Foreigners_recognition Change_LS  
outreg2 using "$OutputT\TableA3_std.tex", replace sum(log) eqkeep(mean sd) dec(2)
restore

preserve
gen Male=1-Female
keep if Immig==0 
keep Male index_participation German Noinvest_reg Noinvest_reg_Low tertiary Prob_training joint joint_disill_invest Prob_Career_Tradeoff Germansucceed 
bysort Male: outreg2 using "$OutputT\TableA3_nonstd.tex", replace sum(log) eqkeep(mean sd) dec(2)
restore


/*** Table A4: Impact of Birthright Citizenship on Subjective Well-Being, Triple Interactions ***/

xi: reg z_ls Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl 
outreg2 using "$OutputT\TableA4.tex", replace keep(Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl) nocons nor2 stats(coef se) tex
xi: reg z_ls Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl i.Bmonth_centered
outreg2 using "$OutputT\TableA4.tex", append keep(Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl) nocons nor2 stats(coef se) tex
xi: reg z_ls Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl i.Bmonth_centered  $FAMILY
outreg2 using "$OutputT\TableA4.tex", append keep(Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl) nocons nor2 stats(coef se) tex
xi: reg z_ls Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl i.Bmonth_centered  $FAMILY  $CITY
outreg2 using "$OutputT\TableA4.tex", append keep(Post Immig Female Treat Post_Girl Immig_Girl Treat_Girl) nocons nor2 stats(coef se) tex


/*** Table A5: Gender Norms ***/

global ggg "ggg_2006_mom ggg_epo_2006_mom ggg_pol_2006_mom ggg_edu_2006_mom ggg_health_2006_mom"
foreach var in $ggg{

local n_`var': variable label `var'
qui su `var' if Immig == 0 
local m0`var' = r(mean)

qui su `var' if Immig == 1 & muslim==1
local m1m`var' = r(mean)

qui su `var' if Immig == 1 & muslim==0
local m1n`var' = r(mean)
}

quietly{
log using "$OutputT\TableA5.tex", text replace
noisily di " & `n_ggg_2006_mom'  & `n_ggg_epo_2006_mom'   & `n_ggg_pol_2006_mom'   & `n_ggg_edu_2006_mom'   & `n_ggg_health_2006_mom'\\ \midline"
noisily di " Natives" "&" round(`m0ggg_2006_mom', .001) "&" round(`m0ggg_epo_2006_mom', .001) "&" round(`m0ggg_pol_2006_mom', .001)  "&" round(`m0ggg_edu_2006_mom', .001) "&" round(`m0ggg_health_2006_mom', .001) "\\"
noisily di " Immigrants & & & & \\"
noisily di " Non-Muslim" "&" round(`m1nggg_2006_mom', .001) "&" round(`m1nggg_epo_2006_mom', .001) "&" round(`m1nggg_pol_2006_mom', .001)  "&" round(`m1nggg_edu_2006_mom', .001) "&" round(`m1nggg_health_2006_mom', .001) "\\"
noisily di " Muslim" "&" round(`m1mggg_2006_mom', .001) "&" round(`m1mggg_epo_2006_mom', .001) "&" round(`m1mggg_pol_2006_mom', .001)  "&" round(`m1mggg_edu_2006_mom') "&" round(`m1mggg_health_2006_mom', .001) "\\"
log close
}

/*** Table A6: Alternative Measures of Traditionality ***/

preserve

tab Birthcountry_Mother, gen(mm)
tab Birthcountry_Father, gen(dd)
reg muslim mm* dd* if Immig==1
predict both_muslim_hat if Immig==1

xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & both_muslim_hat>.74))
outreg2 using "$OutputT\TableA6_PanelA.tex", replace keep(Immig Treat) nocons nor2 stats(coef se) tex
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY   if Female==1 & (Immig==0 |(Immig==1 & both_mcountry==1))
outreg2 using "$OutputT\TableA6_PanelA.tex", append keep(Immig Treat) nocons nor2 stats(coef se) tex
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & both_muslim_hat>.74))
outreg2 using "$OutputT\TableA6_PanelB.tex", replace keep(Immig Treat) nocons nor2 stats(coef se) tex
xi: reg z_ls Post Immig Treat i.Bmonth_centered $FAMILY $CITY  if Female==0 & (Immig==0 |(Immig==1 & both_mcountry==1))
outreg2 using "$OutputT\TableA6_PanelB.tex", append keep(Immig Treat) nocons nor2 stats(coef se) tex

restore


/*** Table A7: Impact of Birthright Citizenship on Academic Achievement ***/

xi: reg gpa_main Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\TableA7_PanelB.tex", replace  keep(Immig Treat) nocons nor2 stats(coef se) tex
xi: reg gpa_main Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==0 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\TableA7_PanelB.tex", append keep(Immig Treat) nocons nor2 stats(coef se) tex
xi: reg gpa_main Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==1))
outreg2 using "$OutputT\TableA7_PanelA.tex", replace keep(Immig Treat) nocons nor2 stats(coef se) tex
xi: reg gpa_main Post Immig Treat i.Bmonth_centered $FAMILY $CITY if Female==1 & (Immig==0 |(Immig==1 & muslim==0))
outreg2 using "$OutputT\TableA7_PanelA.tex", append keep(Immig Treat) nocons nor2 stats(coef se) tex



/*** Erase all redundant output files ***/

cd "$OutputT"

local txtfiles: dir . files "*.txt"
foreach txt in `txtfiles' {
    erase `"`txt'"'
}

local tmpfiles: dir . files "*.tmp"
foreach tmp in `tmpfiles' {
    erase `"`tmp'"'
}

local gphfiles: dir . files "*.gph"
foreach gph in `gphfiles' {
    erase `"`gph'"'
}
