
***** Replication code for Figure 1 in Dahl et al. (2021) "Caught between Cultures: Unintended Consequences of Improving Opportunity for ImImmig Girls" ***

clear
clear matrix
capture log close
set more off

* Enter your global pathway to the project in the following line instead of ... *

global DataC "...\Replication\Data\Clean"
global OutputF "...\Replication\Output\Figures"

/*** Figure 1 ***/

/** Panel B: **/

* To produce this subfigure, replicators have to first run the data preparation code "Survey_citizenship.do", which uses the data file "data_citizenship.dta"

use "$DataC\data_citizenship_survey_collpased.dta", clear

graph bar BR, over(After) blabel(bar ,position(outside)  format(%4.2f)) ylabel(0(0.2)1) title("Panel B: Own Survey") ytitle("Share of Second-Generation Immigrant" "Children with Citizenship at Birth") graphregion(fcolor(white) style(none) color(gs16))
graph save Graph "$OutputF\Figure1_survey.gph", replace

/** Panel A **/

* To produce this subfigure, replicators have to obtain confidential data from the German Microcensus (Wave 2001) from Destatis (www.destatis.de).  
* With this data, run the code "Microcensus_citizenship.do" to prepare the data for this subfigure. We only provide the collapsed data from this exercise in the data file "citizenship_microcensus.dta"

use "$DataC\data_citizenship_microcensus_collpased.dta", clear

graph bar BR, over(After) blabel(bar ,position(outside)  format(%4.2f)) ylabel(0(0.2)1) title("Panel A: German Microcensus, 2001") ytitle("Share of Second-Generation Immigrant" "Children with Citizenship at Birth") graphregion(fcolor(white) style(none) color(gs16))
graph save Graph "$OutputF\Figure1_micro.gph", replace


* Combine Figure 1, Panel A and Figure 1, Panel B 

graph combine "$OutputF\Figure1_micro.gph" "$OutputF\Figure1_survey.gph", cols(2) name(Combine_2w, replace) xsize(8) ysize(4) graphregion(fcolor(white) style(none) color(gs16)) saving("$OutputF\Figure1.gph", replace)

erase "$OutputF\Figure1_micro.gph" 
erase "$OutputF\Figure1_survey.gph"


