
***Data preparation code for Figure 1, Panel A in Dahl et al. (2021) "Caught between Cultures: Unintended Consequences of Improving Opportunity for Immigrant Girls" ***
** Note:  To run this code, confidential data from the German Microcensus (Wave 2001) is needed which can be obtained from Destatis (www.destatis.de) **

* Enter your global pathway to the project in the following line instead of ... *

global DataR "...\Replication\Data\Raw"
global DataC "...\Replication\Data\Clean"

* Enter the name of your microcensus 2001 data file in the following line instead of ... "

use "$DataR\...", clear


keep if ef38==2 & ef33==1999 | ef38==2 & ef33==2000 | ef40==1 & ef33==1999 | ef40==1 & ef33==2000
keep ef32 ef33 ef35 ef43 ef53 id
rename ef32 ef32_child
rename ef33 ef33_child
rename ef35 ef35_child
rename ef53 ef53_child
rename ef43 ef43_child
bysort id: gen howmany=_N
drop if howmany>1
save "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_kids.dta", replace


use "C:\Users\rainer\Dropbox\Immigrant Girls\Data\Mikrozensus2001.dta", clear
save "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_father.dta", replace
gen child=0
replace child=1 if ef38==2 & ef33==1999 | ef38==2 & ef33==2000 | ef40==1 & ef33==1999 | ef40==1 & ef33==2000
bysort id: egen help1=max(child)
gen child_available=0
replace child_available=1 if help1==1 
gen mother=0
replace mother=1 if (ef38==0 | ef38==1) & ef32==2 & child_available==1
keep if mother==1
keep if ef53>=1949 & ef53<=2000
bysort id: gen howmany=_N
drop if howmany>1
keep ef43 ef53 id
rename ef43 ef43_father
rename ef53 ef53_father


save "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_father.dta", replace

use "C:\Users\rainer\Dropbox\Immigrant Girls\Data\Mikrozensus2001.dta", clear
save "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_mother.dta", replace
gen child=0
replace child=1 if ef38==2 & ef33==1999 | ef38==2 & ef33==2000 | ef40==1 & ef33==1999 | ef40==1 & ef33==2000
bysort id: egen help1=max(child)
gen child_available=0
replace child_available=1 if help1==1 
gen father=0
replace father=1 if (ef38==0 | ef38==1) & ef32==1 & child_available==1
keep if father==1
keep if ef53>=1949 & ef53<=2000
bysort id: gen howmany=_N
drop if howmany>1
keep ef43 ef53 id
rename ef43 ef43_mother
rename ef53 ef53_mother
save "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_mother.dta", replace



use "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_kids.dta", clear
merge 1:1 id using "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_mother.dta"
keep if _merge==3
drop _merge
merge 1:1 id using "C:\Users\rainer\Dropbox\Immigrant Girls\Data\MC2001_father.dta"
keep if _merge==3


gen sanguinis=1
replace sanguinis=0 if ef43_father==8 & ef43_mother==8
gen soli=0
replace soli=1 if ef33_child==2000 & (ef53_mother<=1992 | ef53_father<=1992)
tab soli ef33_child
tab soli sanguinis if ef33_child==2000
tab soli sanguinis if ef33_child==1999
gen citizenship_at_birth=0
replace citizenship_at_birth=1 if soli==1 | sanguinis==1
tab citizenship_at_birth ef33_child, col mi
gen BR=citizenship_at_birth
gen After=0 if ef33_child==1999
replace After=1 if ef33_child==2000
keep BR After 
label var BR "Citizenship at birth"
label define nbirth 0 "No" 1 "yes"
label value BR nbirth
label var After "Born after the cutoff date"
label define nafter 0 "Born 1999" 1 "Born 2000"
label value After nafter
collapse BR, by(After)
save "$DataC\data_citizenship_microcensus_collpased.dta", replace
