***Data preparation code for Figure 1, Panel B in Dahl et al. (2021) "Caught between Cultures: Unintended Consequences of Improving Opportunity for Immigrant Girls" ***

clear
clear matrix
capture log close
set more off

* Enter your global pathway to the project in the following line instead of ... *

global DataR "...\Replication\Data\Raw"
global DataC "...\Replication\Data\Clean"


use "$DataR\data_citizenship_survey.dta", clear


* Only keep second generation immigrants (both parents foreign-born)

keep if Born_in_Germany_Mother==0 & Born_in_Germany_Father==0

* Dummy for whether a child was born in the months after January 1, 2000

gen After = 0 if Year_of_Birth<2000
replace After = 1 if Year_of_Birth>=2000

* Muslim Dummy

gen muslim=(Rel_affiliation==4) if Rel_affiliation!=.

* Correcting for inconsistencies (described in footnote 4, p. 7)

drop if Citizenship==. & Citizenship_Timing==.
gen BR=1 if Citizenship==1 & Citizenship_Timing==1
replace BR=0 if Citizenship==0 | Citizenship_Timing==2
replace BR=0 if After==0 & (Citizenship_Mother==0 & Citizenship_Father==0)
replace BR=1 if After==1 & ((Length_Residence_Mother>=22 & Length_Residence_Mother!=.) | (Length_Residence_Father>=22 & Length_Residence_Father!=.))

label var BR "Citizenship at birth"
label define nbirth 0 "No" 1 "yes"
label value BR nbirth
label var After "Born after the cutoff date"
label define nafter 0 "Born 1999" 1 "Born 2000"
label value After nafter


keep BR After

collapse BR, by(After)

save "$DataC\data_citizenship_survey_collpased.dta", replace



